@@ -1,6 +1,6 @@
 /* Handle so called `shell archives'.
 
-   Copyright (C) 1994, 1995, 2007 Free Software Foundation, Inc.
+   Copyright (C) 1994, 1995, 2007, 2010 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,11 +13,10 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+   along with this program; if not, see:  http://www.gnu.org/licenses.
 */
 
-#include "system.h"
+#include "local.h"
 
 /* Basic one-character encoding function to make a char printing.  */
 #define ENCODE_BYTE(Byte) ((((Byte) + 63) & 63) + ' ' + 1)
